OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "最近状态",
    "No recent status changes" : "最近状态没有改变",
    "In a meeting" : "开会中",
    "Commuting" : "通勤中",
    "Out sick" : "生病了",
    "Vacationing" : "度假中",
    "Out of office" : "不在办公室",
    "Working remotely" : "远程办公中",
    "In a call" : "通话中",
    "User status" : "用户状态",
    "Clear status after" : "清除状态于",
    "Emoji for your status message" : "表示状态信息的表情符号",
    "What is your status?" : "你什么状态？",
    "Predefined statuses" : "预定义的状态",
    "Previously set" : "先前设定",
    "Reset status" : "重置状态",
    "Set status" : "设定状态",
    "Online status" : "在线状态",
    "Status message" : "状态信息",
    "Set absence period" : "设置缺勤时段",
    "Set absence period and replacement" : "设置缺勤时段和替代人员",
    "Your status was set automatically" : "您的状态已自动设定",
    "Clear status message" : "清除状态信息",
    "Set status message" : "设定状态信息",
    "Reset status to \"{icon} {message}\"" : "重置状态为 {icon} {message}",
    "Reset status to \"{message}\"" : "重置状态为 {message}",
    "Reset status to \"{icon}\"" : "重置状态为 {icon}",
    "There was an error saving the status" : "保存状态时出错",
    "There was an error clearing the status" : "清除状态时出错",
    "There was an error reverting the status" : "还原状态时发生错误",
    "Don't clear" : "不要清除",
    "Today" : "今天",
    "This week" : "本周",
    "Online" : "在线",
    "Away" : "离开",
    "Do not disturb" : "请勿打扰",
    "Invisible" : "不可见",
    "Offline" : "离线",
    "There was an error saving the new status" : "保存新状态时出错",
    "30 minutes" : "30分钟",
    "1 hour" : "1小时",
    "4 hours" : "4小时",
    "Mute all notifications" : "静音所有通知",
    "Appear offline" : "显示为离线"
},
"nplurals=1; plural=0;");
